# CAVS_style

[![PyPI - Version](https://img.shields.io/pypi/v/cavs-style.svg)](https://pypi.org/project/cavs-style)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/cavs-style.svg)](https://pypi.org/project/cavs-style)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install cavs-style
```

## License

`cavs-style` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license. The Chivo font used in this package is available from [Github](https://github.com/Omnibus-Type/Chivo). The Chivo copyright belongs to the Chivo Project Authors. The font is licensed under the [OFL1.1](https://scripts.sil.org/OFL) license.  
